# Reference
<!-- DO NOT EDIT: This document was generated by Puppet Strings -->

## Table of Contents

**Classes**

_Public Classes_

* [`cron`](#cron): Main entry point into all cron-related resources on the host. It purges by default. You've been warned!

_Private Classes_

* `cron::config`: Various cron configuration files
* `cron::install`: This class handles cron packages.
* `cron::purge`: This is where all the purging magic happens. Purge unmanaged cron jobs and also, optionally, purge `/etc/cron.d` directory.
* `cron::remove`: This class handles removal of all cron-related resources.
* `cron::service`: This class handles cron service.

**Defined types**

* [`cron::job`](#cronjob): Cron job defined type with a bit of magic dust sprinkled all over.
* [`cron::job::daily`](#cronjobdaily): Manage daily cron jobs.
* [`cron::job::hourly`](#cronjobhourly): Manage hourly cron jobs.
* [`cron::job::monthly`](#cronjobmonthly): Manage weekly cron jobs.
* [`cron::job::weekly`](#cronjobweekly): Manage weekly cron jobs.
* [`cron::whitelist`](#cronwhitelist): Use this to whitelist any system cron jobs you don't want this module to touch. This will make sure `/etc/cron.d/${title}` won't get deleted 

**Data types**

* [`Cron::Command`](#croncommand): Used for `cron::job::command` parameter. Does not allow newline characters (which breaks crontab).
* [`Cron::Ensure`](#cronensure): A simple ensure enum
* [`Cron::Hour`](#cronhour): Stricter `cron::job::hour`.
* [`Cron::Minute`](#cronminute): Stricter `cron::job::minute`.
* [`Cron::Month`](#cronmonth): Stricter `cron::job::month`.
* [`Cron::Monthday`](#cronmonthday): Sricter `cron::job::monthday`.
* [`Cron::User`](#cronuser): Cron user.
* [`Cron::Weekday`](#cronweekday): Stricter `cron::job::weekday`.

## Classes

### cron

Main entry point into all cron-related resources on
the host.
It purges by default. You've been warned!

* **See also**
manpages
crontab(1), crontab(5), cron(8)

#### Examples

##### Declaring the cron class

```puppet
include cron
```

##### Also purge unmanaged files in /etc/cron.d directory

```puppet
class { 'cron':
  purge_crond => true,
}
```

##### Removing all cron-related resources from the system

```puppet
class { 'cron':
  ensure => absent,
}
```

##### Deny `crontab(1)` usage to all users except 'luke' (and 'root' - he can always do that).

```puppet
class { 'cron':
  allowed_users => [ 'luke' ],
}
```

#### Parameters

The following parameters are available in the `cron` class.

##### `ensure`

Data type: `Enum[present, absent]`

Whether to enable or disable cron on the system.

Default value: present

##### `package_version`

Data type: `Pattern[/\A[^\n]+\z/]`

Custom `cron` package version.

Default value: installed

##### `allow_all_users`

Data type: `Boolean`

Allow all users to manage crontab.

Default value: `false`

##### `allowed_users`

Data type: `Array[Cron::User]`

List of users allowed to use `crontab(1)`. By default, only root can.

Default value: [ ]

##### `denied_users`

Data type: `Array[Cron::User]`

List of users specifically denied to use `crontab(1)`.
Note: When this is not empty, all users except ones specified here will be able to use `crontab`.

Default value: [ ]

##### `service_manage`

Data type: `Boolean`

Whether to manage cron service at all.

Default value: `true`

##### `service_ensure`

Data type: `Enum[running, stopped]`

Cron service's `ensure` parameter.

Default value: running

##### `service_enable`

Data type: `Boolean`

Cron service's `enable` parameter.

Default value: `true`

##### `purge_cron`

Data type: `Boolean`

Whether to purge crontab entries.

Default value: `true`

##### `purge_crond`

Data type: `Boolean`

Also purge unmanaged files in `/etc/cron.d` directory.

Default value: `false`

##### `purge_noop`

Data type: `Boolean`

Run purging in `noop` mode.

Default value: `false`

## Defined types

### cron::job

Cron job defined type with a bit of magic dust sprinkled all over.

#### Examples

##### Consider cron job declaration using built-in type

```puppet
cron { 'my_job':
  minute => 0,
  hour   => 3,
}
```

##### This differs in that it manages *all* time values by default

```puppet
cron::job { 'my_job':
  minute => 0,
  hour   => 3,
}
```

##### Simple cron job that runs every minute

```puppet
cron::job { 'ping-host':
  command => '/usr/local/bin/my-host-pinger',
}
```

##### More advanced declaration

```puppet
cron::job { 'my-backup':
  command => '/usr/local/bin/my-backup',
  hour    => [ 0, 12 ],
  minute  => '*/10';
}
```

#### Parameters

The following parameters are available in the `cron::job` defined type.

##### `command`

Data type: `Cron::Command`

Command path to be executed

##### `ensure`

Data type: `Cron::Ensure`

Cron job state

Default value: present

##### `user`

Data type: `Cron::User`

The user who owns the cron job

Default value: 'root'

##### `minute`

Data type: `Cron::Minute`

Cron minute

Default value: '*'

##### `hour`

Data type: `Cron::Hour`

Cron hour

Default value: '*'

##### `monthday`

Data type: `Cron::Monthday`

Cron monthday

Default value: '*'

##### `month`

Data type: `Cron::Month`

Cron month

Default value: '*'

##### `weekday`

Data type: `Cron::Weekday`

Cron weekday

Default value: '*'

### cron::job::daily

Manage daily cron jobs.

#### Parameters

The following parameters are available in the `cron::job::daily` defined type.

##### `command`

Data type: `Cron::Command`

Command path to be executed

##### `ensure`

Data type: `Cron::Ensure`

Cron job state

Default value: present

##### `minute`

Data type: `Cron::Minute`

Cron minute

Default value: 0

##### `hour`

Data type: `Cron::Hour`

Cron hour

Default value: 0

##### `user`

Data type: `Cron::User`

The user who owns the cron job

Default value: 'root'

### cron::job::hourly

Manage hourly cron jobs.

#### Parameters

The following parameters are available in the `cron::job::hourly` defined type.

##### `command`

Data type: `Cron::Command`

Command path to be executed

##### `ensure`

Data type: `Cron::Ensure`

Cron job state

Default value: present

##### `minute`

Data type: `Cron::Minute`

Cron minute

Default value: 0

##### `user`

Data type: `Cron::User`

The user who owns the cron job

Default value: 'root'

### cron::job::monthly

Manage weekly cron jobs.

#### Parameters

The following parameters are available in the `cron::job::monthly` defined type.

##### `command`

Data type: `Cron::Command`

Command path to be executed

##### `ensure`

Data type: `Cron::Ensure`

Cron job state

Default value: present

##### `minute`

Data type: `Cron::Minute`

Cron minute

Default value: 0

##### `hour`

Data type: `Cron::Hour`

Cron hour

Default value: 0

##### `monthday`

Data type: `Cron::Monthday`

Cron monthday

Default value: 1

##### `user`

Data type: `Cron::User`

The user who owns the cron job

Default value: 'root'

### cron::job::weekly

Manage weekly cron jobs.

#### Parameters

The following parameters are available in the `cron::job::weekly` defined type.

##### `command`

Data type: `Cron::Command`

Command path to be executed

##### `ensure`

Data type: `Cron::Ensure`

Cron job state

Default value: present

##### `minute`

Data type: `Cron::Minute`

Cron minute

Default value: 0

##### `hour`

Data type: `Cron::Hour`

Cron hour

Default value: 0

##### `weekday`

Data type: `Cron::Weekday`

Cron weekday

Default value: 0

##### `user`

Data type: `Cron::User`

The user who owns the cron job

Default value: 'root'

### cron::whitelist

Use this to whitelist any system cron jobs you don't want this module to touch.
This will make sure `/etc/cron.d/${title}` won't get deleted or modified.

#### Examples

##### Using cron::whitelist resource

```puppet
cron::whitelist { 'sample_name': }
```

## Data types

### Cron::Command

Used for `cron::job::command` parameter.
Does not allow newline characters (which breaks crontab).

Alias of `Pattern[/\A[^\n]+\z/]`

### Cron::Ensure

A simple ensure enum

Alias of `Enum[present, absent]`

### Cron::Hour

Stricter `cron::job::hour`.

Alias of `Variant[Integer[0, 23], Array[Variant[
    Integer[0, 23],
    # Ranges like '0-12', '5-8', etc.
    Pattern[/\A(1?\d|2[0-3])-(1?\d|2[0-3])\z/],
    # Constructs like '*/5', '*/2'
    Pattern[/\A\*\/(1?\d|2[0-3])\z/],
  ], 2], Pattern[/\A(\*|(1?[0-9]|2[0-3])-(1?[0-9]|2[0-3]))(\/([2-9]|1[0-9]|2[0-3]))?\z/]]`

### Cron::Minute

Stricter `cron::job::minute`.

Alias of `Variant[Integer[0, 59], Array[Variant[
    Integer[0, 59],
    # Ranges like '0-37', '30-59', etc.
    Pattern[/\A[0-5]?\d-[0-5]?\d\z/],
    # Patterns like '*/2'
    Pattern[/\A\*\/([2-9]|[1-5]\d)\z/],
  ], 2], Pattern[/\A(\*|[0-5]?\d-[0-5]?\d)(\/([2-9]|[1-5]\d))?\z/]]`

### Cron::Month

Stricter `cron::job::month`.

Alias of `Variant[Integer[1, 12], Array[Integer[1, 12], 2], Pattern[/\A\*(\/([2-9]|1[0-1]))?\z/]]`

### Cron::Monthday

Sricter `cron::job::monthday`.

Alias of `Variant[Integer[1, 31], Array[Integer[1, 31], 2], Pattern[/\A\*(\/([2-9]|[1-2][0-9]|30))?\z/]]`

### Cron::User

Cron user.

Alias of `Pattern[/\A\w[a-z0-9_-]{0,31}\z/]`

### Cron::Weekday

Stricter `cron::job::weekday`.

Alias of `Variant[Integer[0, 6], Array[Integer[0, 6], 2], Pattern[/\A(\*|[0-6]-[0-6])(\/[2-6])?\z/]]`

